==> sdk-0.5.0-sources.jar: com/geopushnetwork/sdk/data/SDKDataContract.java <==
package com.geopushnetwork.sdk.data;

import android.content.ContentResolver;
import android.content.ContentUris;
import android.net.Uri;
import android.provider.BaseColumns;
import android.text.format.Time;

/**
 * Defines table and column names for the weather database.
 */
public class SDKDataContract {

    // The "Content authority" is a name for the entire content provider, similar to the
    // relationship between a domain name and its website.  A convenient string to use for the
    // content authority is the package name for the app, which is guaranteed to be unique on the
    // device.
    public static final String CONTENT_AUTHORITY = "com.geopushnetwork.sdk";

    // Use CONTENT_AUTHORITY to create the base of all URI's which apps will use to contact
    // the content provider.
    public static final Uri BASE_CONTENT_URI = Uri.parse("content://" + CONTENT_AUTHORITY);

    // Possible paths (appended to base content URI for possible URI's)
    // For instance, content://com.example.android.sunshine.app/weather/ is a valid path for
    // looking at weather data. content://com.example.android.sunshine.app/givemeroot/ will fail,
    // as the ContentProvider hasn't been given any information on what to do with "givemeroot".
    // At least, let's hope not.  Don't be that dev, reader.  Don't be that dev.
    public static final String PATH_ADS = "ads";

    // To make it easy to query for the exact date, we normalize all dates that go into
    // the database to the start of the the Julian day at UTC.
    public static long normalizeDate(long startDate) {
        // normalize the start date to the beginning of the (UTC) day
        Time time = new Time();
        time.set(startDate);
        int julianDay = Time.getJulianDay(startDate, time.gmtoff);
        return time.setJulianDay(julianDay);
    }

    /* Inner class that defines the table contents of the weather table */
    public static final class AdEntry implements BaseColumns {

        public static final Uri CONTENT_URI =
                BASE_CONTENT_URI.buildUpon().appendPath(PATH_ADS).build();

        public static final String CONTENT_TYPE =
                ContentResolver.CURSOR_DIR_BASE_TYPE + "/" + CONTENT_AUTHORITY + "/" + PATH_ADS;
        public static final String CONTENT_ITEM_TYPE =
                ContentResolver.CURSOR_ITEM_BASE_TYPE + "/" + CONTENT_AUTHORITY + "/" + PATH_ADS;

        public static final String TABLE_NAME = "ads";

        // Column with the foreign key into the category table.
        public static final String COLUMN_ID = "adid";
        public static final String COLUMN_CATEGORY = "category";
        public static final String COLUMN_ADVERTISER = "advertiser";

        public static final String COLUMN_OLDPRICE = "oldprice";
        public static final String COLUMN_NEWPRICE = "newprice";
        public static final String COLUMN_DISTANCE = "distance";
        public static final String COLUMN_DISCOUNT = "discount";
        public static final String COLUMN_COVER_IMAGE = "coverImage";


        //type of ad
        public static final String COLUMN_TYPE = "type";
        public static final String COLUMN_TITLE = "title";
        public static final String COLUMN_DATE = "date";

        //TODO: ADICIONAR MAIS CAMPOS


        public static Uri buildAdUri() {
            return CONTENT_URI.buildUpon().build();
        }

        public static Uri buildAdUri(long id) {
            return ContentUris.withAppendedId(CONTENT_URI, id);
        }

        public static Uri buildAdCategory(String id) {
            return CONTENT_URI.buildUpon()
                    .appendPath(id).build();
        }

        public static String getCategoryFromUri(Uri uri) {
            return uri.getPathSegments().get(1);
        }


    }
}

==> sdk-0.5.21-sources.jar: com/geopushnetwork/sdk/data/SDKDataContract.java <==
package com.geopushnetwork.sdk.data;

import android.content.ContentResolver;
import android.content.ContentUris;
import android.net.Uri;
import android.provider.BaseColumns;
import android.text.format.Time;
import android.content.Context;

/**
 * Defines table and column names for the weather database.
 */
public class SDKDataContract {




    // The "Content authority" is a name for the entire content provider, similar to the
    // relationship between a domain name and its website.  A convenient string to use for the
    // content authority is the package name for the app, which is guaranteed to be unique on the
    // device.
    public static  String CONTENT_AUTHORITY = ""; //= this.getClass().getPackage().getName();//Context "com.geopushnetwork.sdk";

    // Use CONTENT_AUTHORITY to create the base of all URI's which apps will use to contact
    // the content provider.
    public static  Uri BASE_CONTENT_URI;// = Uri.parse("content://" + CONTENT_AUTHORITY);

    // Possible paths (appended to base content URI for possible URI's)
    // For instance, content://com.example.android.sunshine.app/weather/ is a valid path for
    // looking at weather data. content://com.example.android.sunshine.app/givemeroot/ will fail,
    // as the ContentProvider hasn't been given any information on what to do with "givemeroot".
    // At least, let's hope not.  Don't be that dev, reader.  Don't be that dev.
    public static final String PATH_ADS = "ads";


    public static void Initialize(String contentAuthority){
        CONTENT_AUTHORITY = contentAuthority;
        BASE_CONTENT_URI = Uri.parse(("content://" + CONTENT_AUTHORITY));
    }

    // To make it easy to query for the exact date, we normalize all dates that go into
    // the database to the start of the the Julian day at UTC.
    public static long normalizeDate(long startDate) {
        // normalize the start date to the beginning of the (UTC) day
        Time time = new Time();
        time.set(startDate);
        int julianDay = Time.getJulianDay(startDate, time.gmtoff);
        return time.setJulianDay(julianDay);
    }

    /* Inner class that defines the table contents of the weather table */
    public static final class AdEntry implements BaseColumns {


        public static final Uri CONTENT_URI =
                BASE_CONTENT_URI.buildUpon().appendPath(PATH_ADS).build();

        public static final String CONTENT_TYPE =
                ContentResolver.CURSOR_DIR_BASE_TYPE + "/" + CONTENT_AUTHORITY + "/" + PATH_ADS;
        public static final String CONTENT_ITEM_TYPE =
                ContentResolver.CURSOR_ITEM_BASE_TYPE + "/" + CONTENT_AUTHORITY + "/" + PATH_ADS;

        public static final String TABLE_NAME = "ads";

        // Column with the foreign key into the category table.
        public static final String COLUMN_ID = "adid";
        public static final String COLUMN_CATEGORY = "category";
        public static final String COLUMN_ADVERTISER = "advertiser";

        public static final String COLUMN_OLDPRICE = "oldprice";
        public static final String COLUMN_NEWPRICE = "newprice";
        public static final String COLUMN_DISTANCE = "distance";
        public static final String COLUMN_DISCOUNT = "discount";
        public static final String COLUMN_COVER_IMAGE = "coverImage";


        //type of ad
        public static final String COLUMN_TYPE = "type";
        public static final String COLUMN_TITLE = "title";
        public static final String COLUMN_DATE = "date";

        //TODO: ADICIONAR MAIS CAMPOS


        public static Uri buildAdUri() {
            return CONTENT_URI.buildUpon().build();
        }

        public static Uri buildAdUri(long id) {
            return ContentUris.withAppendedId(CONTENT_URI, id);
        }

        public static Uri buildAdCategory(String id) {
            return CONTENT_URI.buildUpon()
                    .appendPath(id).build();
        }

        public static String getCategoryFromUri(Uri uri) {
            return uri.getPathSegments().get(1);
        }


    }
}
